import 'package:flutter/material.dart';
import 'package:furman_now/src/utils/date_range.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:furman_now/src/widgets/header.dart';
import 'package:furman_now/src/widgets/events/events_list.dart';
import 'package:furman_now/src/widgets/scroll_view_height.dart';
import 'package:intl/intl.dart';

class EventsScreen extends StatelessWidget {
  const EventsScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        color: Colors.grey[100],
        child: SafeArea(
          child: Stack(
            fit: StackFit.loose,
            children: [
              SizedBox(
                width: double.infinity,
                height: double.infinity,
                child: Align(
                  alignment: Alignment.topLeft,
                  child: Container(
                    padding: const EdgeInsets.symmetric(horizontal: 30),
                    width: double.infinity,
                    height: 100,
                    child: Column(
                      mainAxisAlignment: MainAxisAlignment.center,
                      crossAxisAlignment: CrossAxisAlignment.start,
                      children: [
                        Wrap(
                          crossAxisAlignment: WrapCrossAlignment.center,
                          children: [
                            Icon(Icons.calendar_month_outlined, size: 35, color: Colors.grey[700]),
                            const SizedBox(width: 12),
                            Text("Events", style: furmanTextStyle(TextStyle(color: Colors.grey[900], fontSize: 28, fontWeight: FontWeight.w700))),
                          ],
                        ),
                      ],
                    ),
                  ),
                ),
              ),
              ScrollViewWithHeight(
                child: Container(
                  decoration: const BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.vertical(top: Radius.circular(30)),
                  ),
                  padding: const EdgeInsets.symmetric(vertical: 20),
                  margin: const EdgeInsets.only(top: 100),
                  width: double.infinity,
                  child: Column(
                    crossAxisAlignment: CrossAxisAlignment.start,
                    children: [
                      const HeaderWidget(title: "Today"),
                      Padding(
                        padding: const EdgeInsets.symmetric(horizontal: 20),
                        child: EventsList()
                      ),
                      const HeaderWidget(title: "Tomorrow"),
                      Padding(
                          padding: const EdgeInsets.symmetric(horizontal: 20),
                          child: EventsList(dateRange: constructDateRange(
                            DateTime.now().add(const Duration(days: 1)),
                            DateTime.now().add(const Duration(days: 1)),
                          )),
                      ),
                      ...[for(var i=2; i<7; i+=1) i].map((i) {
                        var date = DateTime.now().add(Duration(days: i));
                        var dayName = DateFormat('EEEE').format(date);
                        return Wrap(
                          children: [
                            HeaderWidget(title: dayName),
                            Padding(
                              padding: const EdgeInsets.symmetric(horizontal: 20),
                              child: EventsList(dateRange: constructDateRange(
                                date,
                                date,
                              )),
                            ),
                          ],
                        );
                      }),
                      Center(child:
                        Wrap(
                          direction: Axis.vertical,
                          crossAxisAlignment: WrapCrossAlignment.center,
                          children: const [
                            Text("Need more events?"),
                            Text("Syncdin"),
                            Text("Athletics"),
                            Text("CLPs"),
                          ],
                        ),
                      ),
                    ],
                  ),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
