import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:furman_now/src/routes/index.gr.dart';
import 'package:furman_now/src/utils/greeting.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:furman_now/src/widgets/header.dart';
import 'package:furman_now/src/widgets/events/events_list.dart';
import 'package:furman_now/src/widgets/home/restaurants/restaurants_list.dart';
import 'package:furman_now/src/widgets/home/transportation/transportation_card.dart';
import 'package:furman_now/src/widgets/scroll_view_height.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({Key? key}) : super(key: key);

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  CrossFadeState _showScrollMessage = CrossFadeState.showFirst;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Container(
        color: const Color(0xffb7acc9),
        child: SafeArea(
          child: Container(
            color: Colors.grey[100],
            child: Stack(
              fit: StackFit.loose,
              children: [
                Container(
                  width: double.infinity,
                  height: 300,
                  decoration: const BoxDecoration(
                    gradient: LinearGradient(
                      begin: Alignment.topCenter,
                      end: Alignment.bottomCenter,
                      colors: <Color>[
                        Color(0xffb7acc9),
                        Color(0xffb7acc9),
                      ],
                      tileMode: TileMode.mirror,
                    ),
                  ),
                  child: Align(
                    alignment: Alignment.topLeft,
                    child: Container(
                      padding: const EdgeInsets.all(40),
                      width: double.infinity,
                      height: 200,
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.center,
                        crossAxisAlignment: CrossAxisAlignment.start,
                        children: [
                          Hero(
                            tag: "title",
                            child: Material(
                              type: MaterialType.transparency,
                              child: Text(
                                "${greeting()},\nMichael",
                                style: furmanTextStyle(const TextStyle(
                                  color: Color(0xff26183d),
                                  fontSize: 36,
                                  fontWeight: FontWeight.w800,
                                )),
                              ),
                            ),
                          ),
                          const SizedBox(height: 5),
                          AnimatedCrossFade(
                            crossFadeState: _showScrollMessage,
                            duration: const Duration(milliseconds: 100),
                            firstChild: Text("It's 76º and partly cloudy",
                              style: furmanTextStyle(const TextStyle(
                                color: Color(0xff26183d),
                                fontSize: 16,
                                fontWeight: FontWeight.w500)
                              ),
                            ),
                            secondChild: Text("Pull down to view your Meal ID",
                              style: furmanTextStyle(const TextStyle(
                                  color: Color(0xff26183d),
                                  fontSize: 16,
                                  fontWeight: FontWeight.w500)
                              ),
                            ),
                          ),
                        ],
                      ),
                    ),
                  ),
                ),
                NotificationListener<ScrollNotification>(
                  onNotification: (notification) {
                    if (notification is ScrollUpdateNotification) {
                      final offset = notification.metrics.pixels;
                      if (offset < 0) {
                        var offsetAmount = offset.abs();
                        if (offsetAmount > 50) {
                          context.router.navigate(const StudentIdRoute());
                        } else if (offsetAmount > 20) {
                          setState(() {
                            _showScrollMessage = CrossFadeState.showSecond;
                          });
                        } else {
                          setState(() {
                            _showScrollMessage = CrossFadeState.showFirst;
                          });
                        }
                      } else {
                        if (_showScrollMessage != CrossFadeState.showFirst) {
                          setState(() {
                            _showScrollMessage = CrossFadeState.showFirst;
                          });
                        }
                      }
                    }
                    return true;
                  },
                  child: ScrollViewWithHeight(
                    child: Hero(
                      tag: "card",
                      child: Material(
                        type: MaterialType.transparency,
                        child: Container(
                          decoration: const BoxDecoration(
                            color: Colors.white,
                            borderRadius:
                              BorderRadius.vertical(top: Radius.circular(30)),
                          ),
                          padding: const EdgeInsets.symmetric(vertical: 20),
                          margin: const EdgeInsets.only(top: 200),
                          width: double.infinity,
                          child: Column(
                            crossAxisAlignment: CrossAxisAlignment.start,
                            children: [
                              const HeaderWidget(
                                title: "Today's Events",
                                link: HeaderLink(
                                  text: "View more",
                                  href: EventsRoute()
                                ),
                              ),
                              Padding(
                                padding: const EdgeInsets.symmetric(horizontal: 20),
                                child: EventsList(),
                              ),
                              const HeaderWidget(title: "Food & Dining"),
                              const RestaurantsList(),
                              const HeaderWidget(title: "Transportation"),
                              const Padding(
                                padding: EdgeInsets.symmetric(horizontal: 20),
                                child: TransportationCard(),
                              ),
                            ],
                          ),
                        ),
                      ),
                    ),
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}

