import 'dart:async';

import 'package:auto_route/auto_route.dart';
import 'package:flutter/material.dart';
import 'package:barcode_widget/barcode_widget.dart';
import 'package:furman_now/src/routes/index.gr.dart';
import 'package:furman_now/src/services/get_app/barcode/barcode_service.dart';
import 'package:furman_now/src/utils/theme.dart';

class StudentIdScreen extends StatefulWidget {
  const StudentIdScreen({Key? key}) : super(key: key);

  @override
  State<StudentIdScreen> createState() => _StudentIdScreenState();
}

class _StudentIdScreenState extends State<StudentIdScreen> {
  String barcodeNumber = BarcodeService.generateGetBarcode();
  Timer? timer;

  @override
  void initState() {
    super.initState();

    timer = Timer.periodic(
      const Duration(seconds: 10),
      updateBarcode,
    );
  }

  @override
  void dispose() {
    super.dispose();
    timer?.cancel();
  }

  void updateBarcode(Timer timer) {
    setState(() {
      barcodeNumber = BarcodeService.generateGetBarcode();
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      body: Listener(
        onPointerMove: (details) {
          int sensitivity = 8;
          if (details.delta.dy > sensitivity) {
            // Down Swipe
          } else if (details.delta.dy < -sensitivity) {
            context.router.navigate(const MainLayout());
          }
        },
        child: Container(
          color: const Color(0xffb7acc9),
          child: SafeArea(
            child: ListView(
              padding: const EdgeInsets.all(40),
              children: [
                Text(
                  "Furman ID",
                  style: furmanTextStyle(const TextStyle(color: Color(0xff26183d), fontSize: 36, fontWeight: FontWeight.w800)),
                ),
                const SizedBox(height: 200),
                Container(
                  decoration: const BoxDecoration(
                    color: Colors.white,
                    borderRadius: BorderRadius.all(Radius.circular(10)),
                  ),
                  // hack since the barcode has a weird intrinsic size for some reason
                  child: LayoutBuilder(
                    builder: (BuildContext context, BoxConstraints constraints) {
                      return BarcodeWidget(
                        barcode: Barcode.pdf417(moduleHeight: 4),
                        data: barcodeNumber,
                        margin: const EdgeInsets.all(10),
                        height: constraints.maxWidth / 3,
                      );
                    },
                  ),
                ),
              ],
            ),
          ),
        ),
      ),
    );
  }
}
