import 'package:flutter/material.dart';
import 'package:palette_generator/palette_generator.dart';
import 'package:furman_now/src/services/restaurants/restaurant_service.dart';
import 'package:furman_now/src/utils/theme.dart';

class RestaurantCard extends StatefulWidget {
  const RestaurantCard({
    required this.restaurant,
    Key? key,
  }) : super(key: key);

  final Restaurant restaurant;

  @override
  State<RestaurantCard> createState() => _RestaurantCardState();
}

class _RestaurantCardState extends State<RestaurantCard> {
  PaletteGenerator? paletteGenerator;
  Color? backgroundColor;

  @override
  void initState() {
    super.initState();
    _updatePaletteGenerator();
  }

  Future<void> _updatePaletteGenerator() async {
    paletteGenerator = await PaletteGenerator.fromImageProvider(
      widget.restaurant.image,
      maximumColorCount: 1,
    );
    if (paletteGenerator != null && paletteGenerator!.colors.toList().isNotEmpty) {
      var hslColor = HSLColor.fromColor(paletteGenerator!.colors.toList()[0]);
      var newColor = HSLColor.fromAHSL(1, hslColor.hue, 40/100, 90/100);
      backgroundColor = newColor.toColor();
    }
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      width: 150,
      height: 175,
      decoration: BoxDecoration(
        // color: Color(0xfff9f9fb),
        color: backgroundColor ?? const Color(0xfff9f9fb),
        borderRadius: const BorderRadius.all(Radius.circular(10)),
      ),
      child: Padding(
        padding: const EdgeInsets.all(10),
        child: Column(
          children: [
            Align(
              alignment: Alignment.topLeft,
              child: RichText(
                text: TextSpan(
                  style: furmanTextStyle(TextStyle(
                    color: Colors.grey[800],
                    fontWeight: FontWeight.bold,
                    fontSize: 12,
                  )),
                  children: [
                    WidgetSpan(
                      alignment: PlaceholderAlignment.middle,
                      child: Padding(
                        padding: const EdgeInsets.only(right: 4),
                        child: Container(
                          width: 9,
                          height: 9,
                          decoration: BoxDecoration(
                            color: widget.restaurant.isOpen ? Colors.green : Colors.red.shade700,
                            shape: BoxShape.circle,
                          ),
                        ),
                      ),
                    ),
                    TextSpan(text: widget.restaurant.isOpen ? "Open" : "Closed"),
                  ],
                ),
              ),
            ),
            const SizedBox(height: 10),
            ClipRRect(
              borderRadius: const BorderRadius.all(Radius.circular(5)),
              child: Image.network(widget.restaurant.imageUri, height: 90),
            ),
            Expanded(
              child: Column(
                mainAxisAlignment: MainAxisAlignment.spaceEvenly,
                children: [
                  Text(
                    widget.restaurant.name,
                    textAlign: TextAlign.center,
                    style: furmanTextStyle(TextStyle(
                      color: Colors.grey[800],
                      fontSize: 14,
                      fontWeight: FontWeight.w600,
                    )),
                  ),
                ],
              ),
            ),
          ],
        ),
      ),
    );
  }
}