import 'package:flutter/material.dart';
import 'package:furman_now/src/services/restaurants/restaurant_service.dart';
import 'package:furman_now/src/store/index.dart';
import 'package:provider/provider.dart';

import 'restaurant_card.dart';

class RestaurantsList extends StatefulWidget {
  const RestaurantsList({Key? key}) : super(key: key);

  @override
  State<RestaurantsList> createState() => _RestaurantsListState();
}

class _RestaurantsListState extends State<RestaurantsList> {
  @override
  Widget build(BuildContext context) {
    return Consumer<AppState>(
      builder: (context, state, child) {
        return FutureBuilder<List<Restaurant>>(
          future: state.restaurants,
          builder: (context, snapshot) {
            if (snapshot.hasData) {
              var restaurants = snapshot.data!..sort((r1, r2) => (r1.isOpen ? 0 : 1) - (r2.isOpen ? 0 : 1));
              return SizedBox(
                height: 175,
                child: ListView.builder(
                  padding: const EdgeInsets.only(left: 20),
                  itemCount: restaurants.length,
                  cacheExtent: 10000,
                  scrollDirection: Axis.horizontal,
                  prototypeItem: Padding(
                    padding: const EdgeInsets.only(right: 15),
                    child: RestaurantCard(restaurant: restaurants.first),
                  ),
                  itemBuilder: (context, index) => Padding(
                    padding: const EdgeInsets.only(right: 15),
                    child: RestaurantCard(restaurant: restaurants[index]),
                  ),
                ),
              );
            } else if (snapshot.hasError) {
              return Padding(
                  padding: const EdgeInsets.symmetric(horizontal: 20),
                  child: Text('${snapshot.error}', style: const TextStyle(color: Colors.red))
              );
            }

            // By default, show a loading spinner.
            return const Center(
              child: Padding(
                  padding: EdgeInsets.symmetric(vertical: 25),
                  child: CircularProgressIndicator()
              ),
            );
          },
        );
      },
    );
  }
}